@@ -1,4 +1,4 @@
-/* imczmq.c
+/* omczmq.c
  * Copyright (C) 2014 Brian Knox
  * Copyright (C) 2014 Rainer Gerhards
  *
@@ -56,10 +56,13 @@ typedef struct _pollerData_t {
 
 
 struct instanceConf_s {
+	bool is_server;
+	char *beacon;
+	int beaconPort;
 	int sockType;
 	char *sockEndpoints;
 	char *topicList;
-	char *connType;
+	char *authType;
 	char *clientCertPath;
 	char *serverCertPath;
 	uchar *pszBindRuleset;
@@ -75,6 +78,7 @@ struct modConfData_s {
 };
 
 struct lstn_s {
+	zactor_t *beaconActor;
 	zsock_t *sock;
 	zcert_t *clientCert;
 	zcert_t *serverCert;
@@ -100,9 +104,11 @@ static struct cnfparamblk modpblk = {
 };
 
 static struct cnfparamdescr inppdescr[] = {
+	{ "beacon", eCmdHdlrGetWord, 0 },
+	{ "beaconport", eCmdHdlrGetWord, 0 },
 	{ "endpoints", eCmdHdlrGetWord, 1 },
 	{ "socktype", eCmdHdlrGetWord, 1 },
-	{ "conntype", eCmdHdlrGetWord, 0 },
+	{ "authtype", eCmdHdlrGetWord, 0 },
 	{ "topics", eCmdHdlrGetWord, 0 },
 	{ "clientcertpath", eCmdHdlrGetWord, 0 },
 	{ "servercertpath", eCmdHdlrGetWord, 0 },
@@ -118,10 +124,13 @@ static struct cnfparamblk inppblk = {
 };
 
 static void setDefaults(instanceConf_t* iconf) {
+	iconf->is_server = false;
+	iconf->beacon = NULL;
+	iconf->beaconPort = -1;
 	iconf->sockType = -1;
 	iconf->sockEndpoints = NULL;
 	iconf->topicList = NULL;
-	iconf->connType = NULL;
+	iconf->authType = NULL;
 	iconf->clientCertPath = NULL;
 	iconf->serverCertPath = NULL;
 	iconf->pszBindRuleset = NULL;
@@ -170,6 +179,16 @@ static rsRetVal createListener(struct cnfparamvals* pvals) {
 			inst->sockEndpoints = es_str2cstr(pvals[i].val.d.estr, NULL);
 		} 
 
+		/* get beacon argument */
+		else if (!strcmp(inppblk.descr[i].name, "beacon")) {
+			inst->beacon = es_str2cstr(pvals[i].val.d.estr, NULL);
+		}
+		
+		/* get beacon port */
+		else if (!strcmp(inppblk.descr[i].name, "beaconport")) {
+			inst->beaconPort = atoi(es_str2cstr(pvals[i].val.d.estr, NULL));
+		}
+
 		/* get the socket type */
 		else if(!strcmp(inppblk.descr[i].name, "socktype")){
 			char *stringType = es_str2cstr(pvals[i].val.d.estr, NULL);
@@ -182,10 +201,6 @@ static rsRetVal createListener(struct cnfparamvals* pvals) {
 				inst->sockType = ZMQ_PULL;
 			}
 
-			else if (!strcmp("ROUTER", stringType)) {
-				inst->sockType = ZMQ_ROUTER;
-			}
-
 			else {
 				errmsg.LogError(0, RS_RET_CONFIG_ERROR,
 						"imczmq: invalid sockType");
@@ -205,19 +220,17 @@ static rsRetVal createListener(struct cnfparamvals* pvals) {
 		} 
 	
 		/* get the authentication type to use */
-		else if(!strcmp(inppblk.descr[i].name, "conntype")) {
-			inst->connType = es_str2cstr(pvals[i].val.d.estr, NULL);
+		else if(!strcmp(inppblk.descr[i].name, "authtype")) {
+			inst->authType = es_str2cstr(pvals[i].val.d.estr, NULL);
 
 			/* make sure defined type is supported */
-			if ((inst->connType != NULL) && 
-					strcmp("CURVESERVER", inst->connType) &&
-					strcmp("CURVECLIENT", inst->connType) &&
-					strcmp("CLIENT", inst->connType) &&
-					strcmp("SERVER", inst->connType))
-			{
+			if ((inst->authType != NULL) && 
+					strcmp("CURVESERVER", inst->authType) &&
+					strcmp("CURVECLIENT", inst->authType)) {
+
 				errmsg.LogError(0, RS_RET_CONFIG_ERROR,
-						"imczmq: %s is not a valid connType",
-						inst->connType);
+						"imczmq: %s is not a valid authType",
+						inst->authType);
 				ABORT_FINALIZE(RS_RET_CONFIG_ERROR);
 			}
 		} 
@@ -261,23 +274,42 @@ static rsRetVal addListener(instanceConf_t* iconf){
 		ABORT_FINALIZE(RS_RET_NO_ERRCODE);
 	}
 
-	bool is_server = false;
+	/* if a beacon is set start it */
+	if((iconf->beacon != NULL) && (iconf->beaconPort > 0)) {
+		DBGPRINTF ("imczmq: starting beacon actor...\n");
 
-	DBGPRINTF("imczmq: conntype is: %s\n", iconf->connType);
+		/* create the beacon actor, if it fails abort */	
+		pData->beaconActor = zactor_new(zbeacon, NULL);
+		if (!pData->beaconActor) {
+			errmsg.LogError(0, RS_RET_NO_ERRCODE,
+					"imczmq: could not create beacon service");
+			ABORT_FINALIZE (RS_RET_NO_ERRCODE);
+		}
 
-	if (!strcmp(iconf->connType, "CURVESERVER") || 
-			!stcmp(iconf->connType, "SERVER"))
-	{
-		is_server = true;
-		
-		/* set global auth domain */
-		zsock_set_zap_domain(pData->sock, "global");
+		/* configure the beacon and abort if UDP broadcasting ont available */
+		zsock_send(pData->beaconActor, "si", "CONFIGURE", iconf->beaconPort);
+		char *hostname = zstr_recv(pData->beaconActor);
+		if (!*hostname) {
+			errmsg.LogError(0, RS_RET_NO_ERRCODE,
+					"imczmq: no UDP broadcasting available");
+			ABORT_FINALIZE (RS_RET_NO_ERRCODE);
+		}
+
+		/* start publishing the beacon */
+		zsock_send(pData->beaconActor, "sbi", "PUBLISH", pData->beaconActor, strlen(iconf->beacon));
 	}
 
-	/* if we are a CURVE server */
-	if (!strcmp(iconf->connType, "CURVESERVER")) {
+	DBGPRINTF("imczmq: authtype is: %s\n", iconf->authType);
 
-				/* set that we are a curve server */
+	/* if we are a CURVE server */
+	if (!strcmp(iconf->authType, "CURVESERVER")) {
+
+		iconf->is_server = true;
+
+		/* set global auth domain */
+		zsock_set_zap_domain(pData->sock, "global");
+
+		/* set that we are a curve server */
 		zsock_set_curve_server(pData->sock, 1);
 
 		/* get and set our server cert */
@@ -297,10 +329,10 @@ static rsRetVal addListener(instanceConf_t* iconf){
 	}
 
 	/* if we are a CURVE client */
-	if (!strcmp(iconf->connType, "CURVECLIENT")) {
+	if (!strcmp(iconf->authType, "CURVECLIENT")) {
 		DBGPRINTF("imczmq: we are a curve client...\n");
 
-		is_server = false;
+		iconf->is_server = false;
 
 		/* get our client cert */
 		pData->clientCert = zcert_load(iconf->clientCertPath);
@@ -313,7 +345,7 @@ static rsRetVal addListener(instanceConf_t* iconf){
 		zcert_apply(pData->clientCert, pData->sock);
 
 		/* get the server cert */
-		DBGPRINTF("imczmq: server cert is %s...\n", iconf->serverCertPath);
+		DBGPRINTF("omczmq: server cert is %s...\n", iconf->serverCertPath);
 		pData->serverCert = zcert_load(iconf->serverCertPath);
 		if (!pData->serverCert) {
 			errmsg.LogError(0, NO_ERRCODE, "could not load server cert");
@@ -322,7 +354,7 @@ static rsRetVal addListener(instanceConf_t* iconf){
 
 		/* get the server public key and set it for the socket */
 		char *server_key = zcert_public_txt(pData->serverCert);
-		DBGPRINTF("imczmq: server public key is %s...\n", server_key);
+		DBGPRINTF("omczmq: server public key is %s...\n", server_key);
 		zsock_set_curve_serverkey (pData->sock, server_key);
 	}
 
@@ -619,7 +651,7 @@ CODESTARTfreeCnf
 		free(inst->pszBindRuleset);
 		free(inst->sockEndpoints);
 		free(inst->topicList);
-		free(inst->connType);
+		free(inst->authType);
 		free(inst->clientCertPath);
 		free(inst->serverCertPath);
 		inst_r = inst;
