@@ -48,15 +48,18 @@ static pthread_mutex_t mutDoAct = PTHREAD_MUTEX_INITIALIZER;
 
 typedef struct _instanceData {
 	zactor_t *authActor;
+	zactor_t *beaconActor;
 	zsock_t *sock;
 	zcert_t *clientCert;
 	zcert_t *serverCert;
 	char *sockEndpoints;
 	int sockType;
-	char *connType;
+	char *authType;
 	char *clientCertPath;
 	char *serverCertPath;
 	uchar *tplName;
+	char *beacon;
+	int beaconport;
 } instanceData;
 
 typedef struct wrkrInstanceData {
@@ -66,7 +69,9 @@ typedef struct wrkrInstanceData {
 static struct cnfparamdescr actpdescr[] = {
 	{ "endpoints", eCmdHdlrGetWord, 1 },
 	{ "socktype", eCmdHdlrGetWord, 1 },
-	{ "conntype", eCmdHdlrGetWord, 0 },
+	{ "beacon", eCmdHdlrGetWord, 0 },
+	{ "beaconport", eCmdHdlrGetWord, 0 },
+	{ "authtype", eCmdHdlrGetWord, 0 },
 	{ "clientcertpath", eCmdHdlrGetWord, 0 },
 	{ "servercertpath", eCmdHdlrGetWord, 0 },
 	{ "template", eCmdHdlrGetWord, 0 }
@@ -86,18 +91,18 @@ static rsRetVal initCZMQ(instanceData* pData) {
 
 	/* create new auth actor */
 	DBGPRINTF ("omczmq: starting auth actor...\n");
-	pData->authActor = zactor_new (zauth, NULL);
+	pData->authActor = zactor_new(zauth, NULL);
 	if (!pData->authActor) {
-		errmsg.LogError (0, RS_RET_NO_ERRCODE,
+		errmsg.LogError(0, RS_RET_NO_ERRCODE,
 				"omczmq: could not create auth service");
 		ABORT_FINALIZE (RS_RET_NO_ERRCODE);
 	}
 
 	/* create our zeromq socket */
 	DBGPRINTF ("omczmq: creating zeromq socket...\n");
-	pData->sock = zsock_new (pData->sockType);
+	pData->sock = zsock_new(pData->sockType);
 	if (!pData->sock) {
-		errmsg.LogError (0, RS_RET_NO_ERRCODE,
+		errmsg.LogError(0, RS_RET_NO_ERRCODE,
 				"omczmq: new socket failed for endpoints: %s",
 				pData->sockEndpoints);
 		ABORT_FINALIZE(RS_RET_NO_ERRCODE);
@@ -105,8 +110,33 @@ static rsRetVal initCZMQ(instanceData* pData) {
 
 	bool is_server = false;
 
+	/* if a beacon is set start it */
+	if((pData->beacon != NULL) && (pData->beaconport > 0)) {
+		DBGPRINTF ("omczmq: starting beacon actor...\n");
+
+		/* create the beacon actor, if it fails abort */	
+		pData->beaconActor = zactor_new(zbeacon, NULL);
+		if (!pData->beaconActor) {
+			errmsg.LogError(0, RS_RET_NO_ERRCODE,
+					"omczmq: could not create beacon service");
+			ABORT_FINALIZE (RS_RET_NO_ERRCODE);
+		}
+
+		/* configure the beacon and abort if UDP broadcasting ont available */
+		zsock_send(pData->beaconActor, "si", "CONFIGURE", pData->beaconport);
+		char *hostname = zstr_recv(pData->beaconActor);
+		if (!*hostname) {
+			errmsg.LogError(0, RS_RET_NO_ERRCODE,
+					"omczmq: no UDP broadcasting available");
+			ABORT_FINALIZE (RS_RET_NO_ERRCODE);
+		}
+
+		/* start publishing the beacon */
+		zsock_send(pData->beaconActor, "sbi", "PUBLISH", pData->beacon, strlen(pData->beacon));
+	}
+
 	/* if we are a CURVE server */
-	if (!strcmp(pData->connType, "CURVESERVER")) {
+	if (!strcmp(pData->authType, "CURVESERVER")) {
 		DBGPRINTF("omczmq: we are a curve server...\n");
 		
 		is_server = true;
@@ -134,7 +164,7 @@ static rsRetVal initCZMQ(instanceData* pData) {
 	}
 
 	/* if we are a CURVE client */
-	if (!strcmp(pData->connType, "CURVECLIENT")) {
+	if (!strcmp(pData->authType, "CURVECLIENT")) {
 		DBGPRINTF("omczmq: we are a curve client...\n");
 
 		is_server = false;
@@ -205,7 +235,8 @@ setInstParamDefaults(instanceData* pData) {
 	pData->tplName = NULL;
 	pData->sockType = -1;
 	pData->authActor = NULL;
-	pData->connType = NULL;
+	pData->beaconActor = NULL;
+	pData->authType = NULL;
 	pData->clientCertPath = NULL;
 	pData->serverCertPath = NULL;
 }
@@ -238,11 +269,12 @@ BEGINfreeInstance
 CODESTARTfreeInstance
 	zsock_destroy(&pData->sock);
 	zactor_destroy(&pData->authActor);
+	zactor_destroy(&pData->beaconActor);
 	zcert_destroy(&pData->serverCert);
 	zcert_destroy(&pData->clientCert);
 
 	free(pData->sockEndpoints);
-	free(pData->connType);
+	free(pData->authType);
 	free(pData->clientCertPath);
 	free(pData->serverCertPath);
 	free(pData->tplName);
@@ -312,10 +344,6 @@ CODESTARTnewActInst
 				pData->sockType = ZMQ_PUSH;
 			}
 
-			else if (!strcmp("DEALER", stringType)) {
-				pData->sockType = ZMQ_DEALER;
-			}
-
 			else {
 				errmsg.LogError(0, RS_RET_CONFIG_ERROR,
 						"omczmq: invalid socktype");
@@ -324,19 +352,18 @@ CODESTARTnewActInst
 		} 
 
 		/* get the authentication type to use */
-		else if (!strcmp(actpblk.descr[i].name, "conntype")) {
-			pData->connType = es_str2cstr(pvals[i].val.d.estr, NULL);
+		else if (!strcmp(actpblk.descr[i].name, "authtype")) {
+			pData->authType = es_str2cstr(pvals[i].val.d.estr, NULL);
 
 			/* make sure defined type is supported */
-			if ((inst->connType != NULL) && 
-					strcmp("CURVESERVER", inst->connType) &&
-					strcmp("CURVECLIENT", inst->connType) &&
-					strcmp("CLIENT", inst->connType) &&
-					strcmp("SERVER", inst->connType))
+			if ((pData->authType != NULL) && 
+					strcmp("CURVESERVER", pData->authType) &&
+					strcmp("CURVECLIENT", pData->authType))
 			{
+
 				errmsg.LogError(0, RS_RET_CONFIG_ERROR,
-						"omczmq: %s is not a valid connType",
-						pData->connType);
+						"omczmq: %s is not a valid authType",
+						pData->authType);
 				ABORT_FINALIZE(RS_RET_CONFIG_ERROR);
 			}
 		} 
@@ -351,6 +378,16 @@ CODESTARTnewActInst
 			pData->serverCertPath = es_str2cstr(pvals[i].val.d.estr, NULL);
 		}
 
+		/* get beacon argument */
+		else if (!strcmp(actpblk.descr[i].name, "beacon")) {
+			pData->beacon = es_str2cstr(pvals[i].val.d.estr, NULL);
+		}
+		
+		/* get beacon port */
+		else if (!strcmp(actpblk.descr[i].name, "beaconport")) {
+			pData->beaconport = atoi(es_str2cstr(pvals[i].val.d.estr, NULL));
+		}
+
 		/* the config has a bad option */
 		else {
 			errmsg.LogError(0, NO_ERRCODE, "omczmq: %s is not a valid option",
