@@ -28,6 +28,7 @@
 #include <string.h>
 #include <pthread.h>
 #include <fcntl.h>
+#include <unistd.h>
 #include <sys/uio.h>
 #if defined(__FreeBSD__)
 #include <sys/stat.h>
@@ -434,6 +435,7 @@ CODESTARTactivateCnf
 	/* initialize our own counters */
 	CHKiRet(statsobj.Construct(&statsobj_resources));
 	CHKiRet(statsobj.SetName(statsobj_resources, (uchar*)"resource-usage"));
+	CHKiRet(statsobj.SetOrigin(statsobj_resources, (uchar*)"impstats"));
 	CHKiRet(statsobj.AddCounter(statsobj_resources, UCHAR_CONSTANT("utime"),
 		ctrType_IntCtr, CTR_FLAG_NONE, &st_ru_utime));
 	CHKiRet(statsobj.AddCounter(statsobj_resources, UCHAR_CONSTANT("stime"),
