@@ -209,8 +209,7 @@ readLog(int fd, uchar *pRcv, int iMaxLine)
 		MsgSetInputName(pMsg, pInputName);
 		MsgSetRawMsg(pMsg, (char*)pRcv, strlen((char*)pRcv));
 		MsgSetHOSTNAME(pMsg, glbl.GetLocalHostName(), ustrlen(glbl.GetLocalHostName()));
-		pMsg->iFacility = pri2fac(hdr.pri);
-		pMsg->iSeverity = pri2sev(hdr.pri);
+		msgSetPRI(pMsg, hdr.pri);
 		pMsg->msgFlags = NEEDS_PARSING | NO_PRI_IN_RAW;
 		CHKiRet(submitMsg(pMsg));
 	}
