@@ -243,7 +243,7 @@ CODESTARTdoAction
 		MsgSetParseSuccess(pMsg, 1);
 	}
 
-	msgAddJSON(pMsg, (uchar*)pWrkrData->pData->pszPath + 1, json, 0);
+	msgAddJSON(pMsg, (uchar*)pWrkrData->pData->pszPath + 1, json, 0, 0);
 
 ENDdoAction
 
