@@ -1,7 +1,9 @@
+#!/bin/bash
+# 
 # this shell script provides commands to the common diag system. It enables
 # test scripts to wait for certain conditions and initiate certain actions.
 # needs support in config file.
-# NOTE: this file should be included with "source diag.sh", as it otherwise is
+# NOTE: this file should be included with ". diag.sh", as it otherwise is
 # not always able to convey back states to the upper-level test driver
 # begun 2009-05-27 by rgerhards
 # This file is part of the rsyslog project, released under GPLv3
@@ -12,6 +14,17 @@
 #		"sort" is used. E.g. Solaris needs "gsort"
 #
 
+# environment variables:
+# USE_AUTO_DEBUG "on" --> enables automatic debugging, anything else
+#                turns it off
+
+# diag system internal environment variables
+# these variables are for use by test scripts - they CANNOT be
+# overriden by the user
+# TCPFLOOD_EXTRA_OPTS   enables to set extra options for tcpflood, usually
+#                       used in tests that have a common driver where it
+#                       is too hard to set these options otherwise
+
 #valgrind="valgrind --malloc-fill=ff --free-fill=fe --log-fd=1"
 
 # **** use the line below for very hard to find leaks! *****
@@ -52,6 +65,15 @@ case $1 in
 		# though.
 		mkdir test-spool
 		ulimit -c 4000000000
+		# note: TCPFLOOD_EXTRA_OPTS MUST NOT be unset in init, because
+		# some tests need to set it BEFORE calling init to accomodate
+		# their generic test drivers.
+		if [ "$TCPFLOOD_EXTRA_OPTS" != '' ] ; then
+		        echo TCPFLOOD_EXTRA_OPTS set: $TCPFLOOD_EXTRA_OPTS
+                fi
+		if [ "$USE_AUTO_DEBUG" != 'on' ] ; then
+			rm -f IN_AUTO_DEBUG
+                fi
 		if [ -e IN_AUTO_DEBUG ]; then
 			export valgrind="valgrind --malloc-fill=ff --free-fill=fe --log-fd=1"
 		fi
@@ -64,6 +86,7 @@ case $1 in
 		rm -f rsyslog.input rsyslog.conf.tlscert stat-file1 rsyslog.empty
 		rm -f rsyslog.errorfile
 		rm -f CURRENT_TEST HOSTNAME imfile-state:.-rsyslog.input
+		unset TCPFLOOD_EXTRA_OPTS
 		echo  -------------------------------------------------------------------------------
 		;;
    'es-init')   # initialize local Elasticsearch *testbench* instance for the next
@@ -80,12 +103,12 @@ case $1 in
    'startup')   # start rsyslogd with default params. $2 is the config file name to use
    		# returns only after successful startup, $3 is the instance (blank or 2!)
 		$valgrind ../tools/rsyslogd -C -n -irsyslog$3.pid -M../runtime/.libs:../.libs -f$srcdir/testsuites/$2 &
-   		$srcdir/diag.sh wait-startup $3 || source ./diag.sh error-exit  $?
+   		$srcdir/diag.sh wait-startup $3 || . ./diag.sh error-exit  $?
 		;;
    'startup-vg') # start rsyslogd with default params under valgrind control. $2 is the config file name to use
    		# returns only after successful startup, $3 is the instance (blank or 2!)
 		valgrind --log-fd=1 --error-exitcode=10 --malloc-fill=ff --free-fill=fe --leak-check=full ../tools/rsyslogd -C -n -irsyslog$3.pid -M../runtime/.libs:../.libs -f$srcdir/testsuites/$2 &
-   		$srcdir/diag.sh wait-startup $3 || source ./diag.sh error-exit  $?
+   		$srcdir/diag.sh wait-startup $3 || . ./diag.sh error-exit  $?
 		echo startup-vg still running
 		;;
    'startup-vg-noleak') # same as startup-vg, except that --leak-check is set to "none". This
@@ -94,7 +117,7 @@ case $1 in
 		# they are platform-dependent. In that case, we can't test for leak checks
 		# (obviously), but we can check for access violations, what still is useful.
 		valgrind --log-fd=1 --error-exitcode=10 --malloc-fill=ff --free-fill=fe --leak-check=no ../tools/rsyslogd -C -n -irsyslog$3.pid -M../runtime/.libs:../.libs -f$srcdir/testsuites/$2 &
-   		$srcdir/diag.sh wait-startup $3 || source ./diag.sh error-exit  $?
+   		$srcdir/diag.sh wait-startup $3 || . ./diag.sh error-exit  $?
 		echo startup-vg still running
 		;;
    'wait-startup') # wait for rsyslogd startup ($2 is the instance)
@@ -105,7 +128,7 @@ case $1 in
 			if test $i -gt $TB_TIMEOUT_STARTSTOP
 			then
 			   echo "ABORT! Timeout waiting on startup (pid file)"
-			   source ./diag.sh error-exit 1
+			   . ./diag.sh error-exit 1
 			fi
 		done
 		i=0
@@ -115,7 +138,7 @@ case $1 in
 			if test $i -gt $TB_TIMEOUT_STARTSTOP
 			then
 			   echo "ABORT! Timeout waiting on startup ('started' file)"
-			   source ./diag.sh error-exit 1
+			   . ./diag.sh error-exit 1
 			fi
 		done
 		echo "rsyslogd$2 started with pid " `cat rsyslog$2.pid`
@@ -138,7 +161,7 @@ case $1 in
 		then
 		   echo "ABORT! core file exists, starting interactive shell"
 		   bash
-		   source ./diag.sh error-exit  1
+		   . ./diag.sh error-exit  1
 		fi
 		;;
    'wait-shutdown-vg')  # actually, we wait for rsyslog.pid to be deleted. $2 is the
@@ -150,7 +173,7 @@ case $1 in
 		then
 		   echo "ABORT! core file exists, starting interactive shell"
 		   bash
-		   source ./diag.sh error-exit 1
+		   . ./diag.sh error-exit 1
 		fi
 		;;
    'check-exit-vg') # wait for main message queue to be empty. $2 is the instance.
@@ -163,17 +186,17 @@ case $1 in
    'get-mainqueuesize') # show the current main queue size
 		if [ "$2" == "2" ]
 		then
-			echo getmainmsgqueuesize | ./diagtalker -p13501 || source ./diag.sh error-exit  $?
+			echo getmainmsgqueuesize | ./diagtalker -p13501 || . ./diag.sh error-exit  $?
 		else
-			echo getmainmsgqueuesize | ./diagtalker || source ./diag.sh error-exit  $?
+			echo getmainmsgqueuesize | ./diagtalker || . ./diag.sh error-exit  $?
 		fi
 		;;
    'wait-queueempty') # wait for main message queue to be empty. $2 is the instance.
 		if [ "$2" == "2" ]
 		then
-			echo WaitMainQueueEmpty | ./diagtalker -p13501 || source ./diag.sh error-exit  $?
+			echo WaitMainQueueEmpty | ./diagtalker -p13501 || . ./diag.sh error-exit  $?
 		else
-			echo WaitMainQueueEmpty | ./diagtalker || source ./diag.sh error-exit  $?
+			echo WaitMainQueueEmpty | ./diagtalker || . ./diag.sh error-exit  $?
 		fi
 		;;
    'shutdown-when-empty') # shut rsyslogd down when main queue is empty. $2 is the instance.
@@ -192,16 +215,16 @@ case $1 in
 		;;
    'tcpflood') # do a tcpflood run and check if it worked params are passed to tcpflood
 		shift 1
-		eval ./tcpflood $*
+		eval ./tcpflood $* $TCPFLOOD_EXTRA_OPTS
 		if [ "$?" -ne "0" ]; then
 		  echo "error during tcpflood! see rsyslog.out.log.save for what was written"
 		  cp rsyslog.out.log rsyslog.out.log.save
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		;;
    'injectmsg') # inject messages via our inject interface (imdiag)
 		echo injecting $3 messages
-		echo injectmsg $2 $3 $4 $5 | ./diagtalker || source ./diag.sh error-exit  $?
+		echo injectmsg $2 $3 $4 $5 | ./diagtalker || . ./diag.sh error-exit  $?
 		# TODO: some return state checking? (does it really make sense here?)
 		;;
    'check-mainq-spool') # check if mainqueue spool files exist, if not abort (we just check .qi).
@@ -210,7 +233,7 @@ case $1 in
 		if test ! -f test-spool/mainq.qi; then
 		  echo "error: mainq.qi does not exist where expected to do so!"
 		  ls -l test-spool
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		;;
    'seq-check') # do the usual sequence check to see if everything was properly received. $2 is the instance.
@@ -222,7 +245,7 @@ case $1 in
 		./chkseq -fwork -s$2 -e$3 $4 $5 $6 $7
 		if [ "$?" -ne "0" ]; then
 		  echo "sequence error detected"
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		;;
    'seq-check2') # do the usual sequence check to see if everything was properly received. This is
@@ -235,7 +258,7 @@ case $1 in
 		./chkseq -fwork2 -s$2 -e$3 $4 $5 $6 $7
 		if [ "$?" -ne "0" ]; then
 		  echo "sequence error detected"
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		rm -f work2
 		;;
@@ -243,20 +266,27 @@ case $1 in
 		cat rsyslog.out.log | grep -qF "$2"
 		if [ "$?" -ne "0" ]; then
 		    echo content-check failed
-		    source ./diag.sh error-exit 1
+		    . ./diag.sh error-exit 1
 		fi
 		;;
    'custom-content-check') 
 		cat $3 | grep -qF "$2"
 		if [ "$?" -ne "0" ]; then
 		    echo content-check failed to find "'$2'" inside "'$3'"
-		    source ./diag.sh error-exit 1
+		    . ./diag.sh error-exit 1
+		fi
+		;;
+   'content-pattern-check') 
+		cat rsyslog.out.log | grep -q "$2"
+		if [ "$?" -ne "0" ]; then
+		    echo content-check failed, not every line matched pattern "'$2'"
+		    . ./diag.sh error-exit 1
 		fi
 		;;
    'assert-content-missing') 
 		cat rsyslog.out.log | grep -qF "$2"
 		if [ "$?" -eq "0" ]; then
-		    source ./diag.sh error-exit 1
+		    . ./diag.sh error-exit 1
 		fi
 		;;
    'gzip-seq-check') # do the usual sequence check, but for gzip files
@@ -268,14 +298,14 @@ case $1 in
 		./chkseq -fwork -v -s$2 -e$3 $4 $5 $6 $7
 		if [ "$?" -ne "0" ]; then
 		  echo "sequence error detected"
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		;;
    'nettester') # perform nettester-based tests
    		# use -v for verbose output!
 		./nettester -t$2 -i$3 $4
 		if [ "$?" -ne "0" ]; then
-		  source ./diag.sh error-exit 1
+		  . ./diag.sh error-exit 1
 		fi
 		;;
    'setzcat')   # find out name of zcat tool
@@ -286,17 +316,17 @@ case $1 in
 		fi
 		;;
    'generate-HOSTNAME')   # generate the HOSTNAME file
-		source $srcdir/diag.sh startup gethostname.conf || source ./diag.sh error-exit  $?
-		source $srcdir/diag.sh tcpflood -m1 -M "\"<128>\"" || source ./diag.sh error-exit  $?
+		. $srcdir/diag.sh startup gethostname.conf || . ./diag.sh error-exit  $?
+		. $srcdir/diag.sh tcpflood -m1 -M "\"<128>\"" || . ./diag.sh error-exit  $?
 		./msleep 100
-		source $srcdir/diag.sh shutdown-when-empty || source ./diag.sh error-exit  $?  # shut down rsyslogd when done processing messages
-		source $srcdir/diag.sh wait-shutdown || source ./diag.sh error-exit  $?	# we need to wait until rsyslogd is finished!
+		. $srcdir/diag.sh shutdown-when-empty || . ./diag.sh error-exit  $?  # shut down rsyslogd when done processing messages
+		. $srcdir/diag.sh wait-shutdown || . ./diag.sh error-exit  $?	# we need to wait until rsyslogd is finished!
 		;;
    'error-exit') # this is called if we had an error and need to abort. Here, we
                 # try to gather as much information as possible. That's most important
 		# for systems like Travis-CI where we cannot debug on the machine itself.
 		# our $2 is the to-be-used exit code.
-		if [ ! -e IN_AUTO_DEBUG ]; then
+		if [[ ! -e IN_AUTO_DEBUG &&  "$USE_AUTO_DEBUG" == 'on' ]]; then
 			touch IN_AUTO_DEBUG
 			if [ -e core* ]
 			then
