@@ -1,8 +1,9 @@
+#!/bin/bash
 # This is part of the rsyslog testbench, licensed under ASL 2.0
 echo ======================================================================
 echo [imfile-readmode2-with-persists.sh]
-source $srcdir/diag.sh init
-source $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
+. $srcdir/diag.sh init
+. $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
 
 # write the beginning of the file
 echo 'msgnum:0
@@ -16,10 +17,10 @@ sleep 1
 # persisted and read again on startup. Results should still be
 # correct ;)
 echo stopping rsyslog
-source $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-source $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
+. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+. $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
 echo restarting rsyslog
-source $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
+. $srcdir/diag.sh startup imfile-readmode2-with-persists.conf
 echo restarted rsyslog, continuing with test
 
 # write some more lines (see https://github.com/rsyslog/rsyslog/issues/144)
@@ -30,8 +31,8 @@ echo 'msgnum:5' >> rsyslog.input # this one shouldn't be written to the output f
 # give it time to finish
 sleep 1
 
-source $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
-source $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
+. $srcdir/diag.sh shutdown-when-empty # shut down rsyslogd when done processing messages
+. $srcdir/diag.sh wait-shutdown    # we need to wait until rsyslogd is finished!
 
 # give it time to write the output file
 sleep 1
@@ -65,4 +66,4 @@ done
 
 ## if we got here, all is good :)
 
-source $srcdir/diag.sh exit
+. $srcdir/diag.sh exit
